netapp_ontap.models.nfs_service_windows API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nfs_service_windows`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NfsServiceWindowsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsServiceWindows object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `default_user: str GET POST PATCH`

    Specifies the default Windows user for the NFS server.

  `map_unknown_uid_to_default_user: bool GET POST PATCH`

    Specifies whether or not the mapping of an unknown UID to the default Windows user is enabled.

  `v3_ms_dos_client_enabled: bool GET POST PATCH`

    Specifies whether NFSv3 MS-DOS client support is enabled.